==> ejc-bfyjerp-impl-3.0.0-20250618.102043-226-sources.jar: com/ejianc/business/supply/service/impl/SupplyApplyBpmServiceImpl.java <==
package com.ejianc.business.supply.service.impl;

import com.ejianc.business.supply.bean.SupplyApplyEntity;
import com.ejianc.business.supply.service.ISupplyApplyService;
import com.ejianc.foundation.share.vo.SupplierVO;
import com.ejianc.foundation.support.api.ISupplierApi;
import com.ejianc.framework.core.exception.BusinessException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.util.Arrays;
import java.util.Map;

@Service("supplyApply") 
public class SupplyApplyBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private ISupplyApplyService service;
	@Autowired
	private ISupplierApi supplierApi;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批后回调
	 *
	 * @param billId	//单据id
	 * @param state		//单据状态
	 * @param billTypeCode		//单据类型code
	 * @param taskId		//该流程id
	 * @param isEnd		//该节点是否结束
	 * @return
	 */
	@Override
	public CommonResponse<String> afterInApprovalBack(Long billId, Integer state, String billTypeCode, String taskId, Boolean isEnd, String sign, Map<String,Object> other){
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		SupplyApplyEntity supplyApplyEntity = service.selectById(billId);
		SupplierVO supplierVO = new SupplierVO();
		supplierVO.setSourceId(supplyApplyEntity.getId().toString());
		supplierVO.setName(supplyApplyEntity.getName());
		supplierVO.setSocialCreditCode(supplyApplyEntity.getSocialCreditCode());
		supplierVO.setAddress(supplyApplyEntity.getRegisterPlace());
		supplierVO.setLegal(supplyApplyEntity.getLegalPerson());
		supplierVO.setCategoryId(supplyApplyEntity.getSupplyType());
		supplierVO.setCategoryName(supplyApplyEntity.getSupplyTypeName());
		supplierVO.setBusinessScope(supplyApplyEntity.getBusinessScope());
		supplierVO.setEnabled(1);
		CommonResponse<SupplierVO> response = supplierApi.saveOrUpdate(supplierVO);
		if (!response.isSuccess()){
			throw new BusinessException("供应商档案插入失败！");
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		SupplyApplyEntity supplyApplyEntity = service.selectById(billId);
		CommonResponse<String> response = supplierApi.delete(Arrays.asList(supplyApplyEntity.getId()));
		if (!response.isSuccess()){
			throw new BusinessException("删除供应商失败！");
		}
		return CommonResponse.success();
	}

}

==> ejc-bfyjerp-impl-3.0.0-20250930.013332-297-sources.jar: com/ejianc/business/supply/service/impl/SupplyApplyBpmServiceImpl.java <==
package com.ejianc.business.supply.service.impl;

import com.ejianc.business.supply.bean.SupplyApplyEntity;
import com.ejianc.business.supply.service.ISupplyApplyService;
import com.ejianc.foundation.share.vo.SupplierVO;
import com.ejianc.foundation.support.api.ISupplierApi;
import com.ejianc.framework.core.exception.BusinessException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.util.Arrays;
import java.util.Map;

@Service("supplyApply") 
public class SupplyApplyBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private ISupplyApplyService service;
	@Autowired
	private ISupplierApi supplierApi;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批后回调
	 *
	 * @param billId	//单据id
	 * @param state		//单据状态
	 * @param billTypeCode		//单据类型code
	 * @param taskId		//该流程id
	 * @param isEnd		//该节点是否结束
	 * @return
	 */
	@Override
	public CommonResponse<String> afterInApprovalBack(Long billId, Integer state, String billTypeCode, String taskId, Boolean isEnd, String sign, Map<String,Object> other){
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		SupplyApplyEntity supplyApplyEntity = service.selectById(billId);
		SupplierVO supplierVO = new SupplierVO();
		supplierVO.setSourceId(supplyApplyEntity.getId().toString());
		supplierVO.setName(supplyApplyEntity.getName());
		supplierVO.setSocialCreditCode(supplyApplyEntity.getSocialCreditCode());
		supplierVO.setAddress(supplyApplyEntity.getRegisterPlace());
		supplierVO.setLegal(supplyApplyEntity.getLegalPerson());
		supplierVO.setCategoryId(supplyApplyEntity.getSupplyType());
		supplierVO.setCategoryName(supplyApplyEntity.getSupplyTypeName());
		supplierVO.setBusinessScope(supplyApplyEntity.getBusinessScope());
		supplierVO.setEnabled(1);
		CommonResponse<SupplierVO> response = supplierApi.saveOrUpdate(supplierVO);
		if (!response.isSuccess()){
			throw new BusinessException("供应商档案插入失败:"+response.getMsg());
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		SupplyApplyEntity supplyApplyEntity = service.selectById(billId);
		CommonResponse<String> response = supplierApi.delete(Arrays.asList(supplyApplyEntity.getId()));
		if (!response.isSuccess()){
			throw new BusinessException("删除供应商失败！");
		}
		return CommonResponse.success();
	}

}
